/********************************** (C) COPYRIGHT *******************************
 * File Name          : main.c
 * Author             : WCH
 * Version            : V1.0.0
 * Date               : 2022/05/31
 * Description        : Main program body.
*********************************************************************************
* Copyright (c) 2021 Nanjing Qinheng Microelectronics Co., Ltd.
* Attention: This software (modified or not) and binary are used for 
* microcontroller manufactured by Nanjing Qinheng Microelectronics.
*******************************************************************************/
/*
 *@Note
UDP Client example, demonstrating that UDP Client receives data and sends back.
For details on the selection of engineering chips,
please refer to the "CH32V30x Evaluation Board Manual" under the CH32V307EVT\EVT\PUB folder.
 */

#include "string.h"
#include "debug.h"
#include "wchnet.h"
#include "eth_driver.h"

#define UDP_RECE_BUF_LEN                1472
u8 MACAddr[6];                                              //MAC address
u8 IPAddr[4] = { 192, 168, 1, 10 };                         //IP address
u8 GWIPAddr[4] = { 192, 168, 1, 1 };                        //Gateway IP address
u8 IPMask[4] = { 255, 255, 255, 0 };                        //subnet mask
u8 DESIP[4] = { 192, 168, 1, 103 };                         //destination IP address
u16 desport = 1000;                                         //destination port
u16 srcport = 1000;                                         //source port

u8 SocketId;
u8 SocketRecvBuf[WCHNET_MAX_SOCKET_NUM][UDP_RECE_BUF_LEN];      //socket receive buffer
u8 MyBuf[UDP_RECE_BUF_LEN];
u16 Adc_Val[240];
/* Global Variable */
u16 TxBuf[1024];
s16 Calibrattion_Val = 0;
/*********************************************************************
 * @fn      mStopIfError
 *
 * @brief   check if error.
 *
 * @param   iError - error constants.
 *
 * @return  none
 */
void mStopIfError(u8 iError)
{
    if (iError == WCHNET_ERR_SUCCESS)
        return;
    printf("Error: %02X\r\n", (u16) iError);
}

/*********************************************************************
 * @fn      TIM2_Init
 *
 * @brief   Initializes TIM2.
 *
 * @return  none
 */
void TIM2_Init(void)
{
    TIM_TimeBaseInitTypeDef TIM_TimeBaseStructure = { 0 };

    RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM2, ENABLE);

    TIM_TimeBaseStructure.TIM_Period = SystemCoreClock / 1000000 - 1;
    TIM_TimeBaseStructure.TIM_Prescaler = WCHNETTIMERPERIOD * 1000 - 1;
    TIM_TimeBaseStructure.TIM_ClockDivision = 0;
    TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;
    TIM_TimeBaseInit(TIM2, &TIM_TimeBaseStructure);
    TIM_ITConfig(TIM2, TIM_IT_Update, ENABLE);

    TIM_Cmd(TIM2, ENABLE);
    TIM_ClearITPendingBit(TIM2, TIM_IT_Update);
    NVIC_EnableIRQ(TIM2_IRQn);
}

/*********************************************************************
 * @fn      WCHNET_CreateUdpSocket
 *
 * @brief   Create UDP Socket
 *
 * @return  none
 */
void WCHNET_CreateUdpSocket(void)
{
    u8 i;
    SOCK_INF TmpSocketInf;

    memset((void *) &TmpSocketInf, 0, sizeof(SOCK_INF));
    memcpy((void *) TmpSocketInf.IPAddr, DESIP, 4);
    TmpSocketInf.DesPort = desport;
    TmpSocketInf.SourPort = srcport;
    TmpSocketInf.ProtoType = PROTO_TYPE_UDP;
    TmpSocketInf.RecvStartPoint = (u32) SocketRecvBuf[SocketId];
    TmpSocketInf.RecvBufLen = UDP_RECE_BUF_LEN;
    i = WCHNET_SocketCreat(&SocketId, &TmpSocketInf);
    printf("WCHNET_SocketCreat %d\r\n", SocketId);
    mStopIfError(i);
}

/*********************************************************************
 * @fn      WCHNET_DataLoopback
 *
 * @brief   Data loopback function.
 *
 * @param   id - socket id.
 *
 * @return  none
 */
void WCHNET_DataLoopback(u8 id)
{
#if 1
    u8 i;
    u32 len;
    u32 endAddr = SocketInf[id].RecvStartPoint + SocketInf[id].RecvBufLen;       //Receive buffer end address

    if ((SocketInf[id].RecvReadPoint + SocketInf[id].RecvRemLen) > endAddr) {    //Calculate the length of the received data
        len = endAddr - SocketInf[id].RecvReadPoint;
    }
    else {
        len = SocketInf[id].RecvRemLen;
    }
    i = WCHNET_SocketSend(id, (u8 *) SocketInf[id].RecvReadPoint, &len);        //send data
    printf("id=%d\r\n",id);
    if (i == WCHNET_ERR_SUCCESS) {
        WCHNET_SocketRecv(id, NULL, &len);                                      //Clear sent data
    }
#else
    u32 len, totallen;
    u8 *p = MyBuf;

    len = WCHNET_SocketRecvLen(id, NULL);                                //query length
    printf("Receive Len = %02x\n", len);
    totallen = len;
    WCHNET_SocketRecv(id, MyBuf, &len);                                  //Read the data of the receive buffer into MyBuf
    while(1){
        len = totallen;
        WCHNET_SocketSend(id, p, &len);                                  //Send the data
        totallen -= len;                                                 //Subtract the sent length from the total length
        p += len;                                                        //offset buffer pointer
        if(totallen)continue;                                            //If the data is not sent, continue to send
        break;                                                           //After sending, exit
    }
#endif
}

/*********************************************************************
 * @fn      WCHNET_HandleSockInt
 *
 * @brief   Socket Interrupt Handle
 *
 * @param   socketid - socket id.
 *          intstat - interrupt status
 *
 * @return  none
 */
void WCHNET_HandleSockInt(u8 socketid, u8 intstat)
{
    if (intstat & SINT_STAT_RECV)                             //receive data
    {
        WCHNET_DataLoopback(socketid);                        //Data loopback
    }
    if (intstat & SINT_STAT_CONNECT)                          //connect successfully
    {
        printf("TCP Connect Success\r\n");
    }
    if (intstat & SINT_STAT_DISCONNECT)                       //disconnect
    {
        printf("TCP Disconnect\r\n");
    }
    if (intstat & SINT_STAT_TIM_OUT)                          //timeout disconnect
    {
        printf("TCP Timeout\r\n");
    }
}

/*********************************************************************
 * @fn      WCHNET_HandleGlobalInt
 *
 * @brief   Global Interrupt Handle
 *
 * @return  none
 */
void WCHNET_HandleGlobalInt(void)
{
    u8 intstat;
    u16 i;
    u8 socketint;

    intstat = WCHNET_GetGlobalInt();                          //get global interrupt flag
    if (intstat & GINT_STAT_UNREACH)                          //Unreachable interrupt
    {
        printf("GINT_STAT_UNREACH\r\n");
    }
    if (intstat & GINT_STAT_IP_CONFLI)                        //IP conflict
    {
        printf("GINT_STAT_IP_CONFLI\r\n");
    }
    if (intstat & GINT_STAT_PHY_CHANGE)                       //PHY status change
    {
        i = WCHNET_GetPHYStatus();
        if (i & PHY_Linked_Status)
            printf("PHY Link Success\r\n");
    }
    if (intstat & GINT_STAT_SOCKET) {
        for (i = 0; i < WCHNET_MAX_SOCKET_NUM; i++) {         //socket related interrupt
            socketint = WCHNET_GetSocketInt(i);
            if (socketint)
                WCHNET_HandleSockInt(i, socketint);
        }
    }
}

///*********************************************************************
// * @fn      ADC_Function_Init
// *
// * @brief   Initializes ADC collection.
// *
// * @return  none
// */
//void TIM1_Generate_CC1 (u16 arr, u16 psc, u16 ccp)
//{
//
//    GPIO_InitTypeDef GPIO_InitStructure={0};
//    TIM_OCInitTypeDef TIM_OCInitStructure={0};
//    TIM_TimeBaseInitTypeDef TIM_TimeBaseStructure={0};
//
//    RCC_APB2PeriphClockCmd( RCC_APB2Periph_GPIOA | RCC_APB2Periph_TIM1, ENABLE );
//
////    GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8;
////    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
////    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
////    GPIO_Init( GPIOA, &GPIO_InitStructure );
//
//    TIM_TimeBaseStructure.TIM_Period = arr;
//    TIM_TimeBaseStructure.TIM_Prescaler = psc;
//    TIM_TimeBaseStructure.TIM_ClockDivision = TIM_CKD_DIV1;
//    TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;
//    TIM_TimeBaseInit( TIM1, &TIM_TimeBaseStructure);
//
////    TIM_OCInitStructure.TIM_OCMode = TIM_OCMode_PWM1;
////    TIM_OCInitStructure.TIM_OutputState = TIM_OutputState_Enable;
////    TIM_OCInitStructure.TIM_Pulse = ccp;
////    TIM_OCInitStructure.TIM_OCPolarity = TIM_OCPolarity_Low;
////    TIM_OC1Init( TIM1, &TIM_OCInitStructure );
//    TIM_InternalClockConfig(TIM1);
////    TIM_CtrlPWMOutputs(TIM1, ENABLE );
//    TIM_OC1PreloadConfig( TIM1, TIM_OCPreload_Enable );
//    TIM_ARRPreloadConfig( TIM1, ENABLE );
////    TIM_UpdateDisableConfig(TIM2, DISABLE);
//   // TIM_GenerateEvent(TIM1,TIM_EventSource_CC1);
//    TIM_Cmd( TIM1, ENABLE );
//
//}
void TIM3_IRQHandler(void) __attribute__((interrupt("WCH-Interrupt-fast")));

//定时器初始化
void Time_Init(void)
{
     TIM_TimeBaseInitTypeDef TIM_TimeBaseInitStructure;
     NVIC_InitTypeDef        NVIC_InitStructure;

     RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM3,ENABLE);

     TIM_TimeBaseInitStructure.TIM_Period = 199;                      //设置0.2ms采样一次
     TIM_TimeBaseInitStructure.TIM_Prescaler = 71;
     TIM_TimeBaseInitStructure.TIM_ClockDivision = TIM_CKD_DIV1;      //时钟分频，TIM3是通用定时器，基本定时器不用设置
     TIM_TimeBaseInitStructure.TIM_CounterMode = TIM_CounterMode_Up;  //向上扫描
     TIM_TimeBaseInit(TIM3, &TIM_TimeBaseInitStructure);

     TIM_SelectOutputTrigger(TIM3, TIM_TRGOSource_Update);            //选择TRGO作为触发源为定时器更新时间

     TIM_ITConfig(TIM3,TIM_IT_Update,ENABLE);
     TIM_ClearITPendingBit(TIM3, TIM_IT_Update);                      //清中断以免一启用中断后立即产生中断

     NVIC_InitStructure.NVIC_IRQChannel = TIM3_IRQn;
     NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
     NVIC_InitStructure.NVIC_IRQChannelSubPriority = 3;
     NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
     NVIC_Init(&NVIC_InitStructure);

     TIM_Cmd(TIM3,ENABLE);                                            //使能定时中断
}


void TIM3_IRQHandler()
{
//    printf("\r\nEnter TIM3 interrupt\r\n");
    if( TIM_GetITStatus( TIM3, TIM_IT_Update) != RESET )
    {
//        printf("\r\nEnter TIM interrupt\r\n");
//        changeInject++;
    }
    TIM_ClearITPendingBit(TIM3, TIM_IT_Update);                      //清中断以免一启用中断后立即产生中断
}
/*********************************************************************
 * @fn      ADC_Function_Init
 *
 * @brief   Initializes ADC collection.
 *
 * @return  none
 */
void ADC_Function_Init(void)
{
//    ADC_InitTypeDef ADC_InitStructure={0};
//    GPIO_InitTypeDef GPIO_InitStructure={0};
//
//    RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA, ENABLE );
//    RCC_APB2PeriphClockCmd(RCC_APB2Periph_ADC1, ENABLE );
//    RCC_ADCCLKConfig(RCC_PCLK2_Div8);
//
//    GPIO_InitStructure.GPIO_Pin = GPIO_Pin_1;
//    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AIN;
//    GPIO_Init(GPIOA, &GPIO_InitStructure);
//
//    ADC_DeInit(ADC1);
//    ADC_InitStructure.ADC_Mode = ADC_Mode_Independent;
//    ADC_InitStructure.ADC_ScanConvMode = DISABLE;
//    ADC_InitStructure.ADC_ContinuousConvMode = ENABLE;
//    ADC_InitStructure.ADC_ExternalTrigConv = ADC_ExternalTrigConv_T3_TRGO;
//    ADC_InitStructure.ADC_DataAlign = ADC_DataAlign_Right;
//    ADC_InitStructure.ADC_NbrOfChannel = 1;
//    ADC_Init(ADC1, &ADC_InitStructure);
//    ADC_RegularChannelConfig(ADC1, ADC_Channel_1, 1, ADC_SampleTime_28Cycles5);
//    ADC_Cmd(ADC1, ENABLE);
//
//    ADC_BufferCmd(ADC1, DISABLE);   //disable buffer
//    ADC_ResetCalibration(ADC1);
//    while(ADC_GetResetCalibrationStatus(ADC1));
//    ADC_StartCalibration(ADC1);
//    while(ADC_GetCalibrationStatus(ADC1));
//    Calibrattion_Val = Get_CalibrationValue(ADC1);
//    // 使能ADC DMA 请求
//    ADC_DMACmd(ADC1, ENABLE);
    GPIO_InitTypeDef GPIO_InitStructure;
    ADC_InitTypeDef  ADC_InitStructure;

    RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA |RCC_APB2Periph_ADC1 , ENABLE );          //使能GPIOA时钟和ADC

    GPIO_InitStructure.GPIO_Pin = GPIO_Pin_1;
    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AIN;                                         //GPIO模式为模拟输入
    GPIO_Init(GPIOA, &GPIO_InitStructure);

    RCC_ADCCLKConfig(RCC_PCLK2_Div8);                                                     //设置ADC时钟分频为6分频

    ADC_DeInit(ADC1);
    ADC_InitStructure.ADC_Mode = ADC_Mode_Independent;                                    //配置ADC为独立模式
    ADC_InitStructure.ADC_ScanConvMode = DISABLE;                                          //多通道模式下开启扫描模式
    ADC_InitStructure.ADC_ContinuousConvMode = DISABLE;                                    //设置开启连续转换模式
    ADC_InitStructure.ADC_ExternalTrigConv = ADC_ExternalTrigConv_T3_TRGO;                //定时器3外部触发
    ADC_InitStructure.ADC_DataAlign = ADC_DataAlign_Right;                                //设置ADC数据右对齐
    ADC_InitStructure.ADC_NbrOfChannel = 1;                                          //规则转换的ADC通道的数目
    ADC_Init(ADC1, &ADC_InitStructure);                                                   //根据ADC_InitStructure中指定的参数初始化ADC1寄存器

    ADC_Cmd(ADC1, ENABLE);                       //使能ADC1
    ADC_DMACmd(ADC1, ENABLE);
    ADC_ExternalTrigConvCmd(ADC1, ENABLE);       //设置外部触发模式使能

    ADC_ResetCalibration(ADC1);                  //重置ADC1校准寄存器。

    while(ADC_GetResetCalibrationStatus(ADC1));  //等待复位校准结束

    ADC_StartCalibration(ADC1);                  //开启AD校准

    while(ADC_GetCalibrationStatus(ADC1));       //等待校准结束
}

/*********************************************************************
 * @fn      Get_ADC_Val
 *
 * @brief   Returns ADCx conversion result data.
 *
 * @param   ch - ADC channel.
 *            ADC_Channel_0 - ADC Channel0 selected.
 *            ADC_Channel_1 - ADC Channel1 selected.
 *            ADC_Channel_2 - ADC Channel2 selected.
 *            ADC_Channel_3 - ADC Channel3 selected.
 *            ADC_Channel_4 - ADC Channel4 selected.
 *            ADC_Channel_5 - ADC Channel5 selected.
 *            ADC_Channel_6 - ADC Channel6 selected.
 *            ADC_Channel_7 - ADC Channel7 selected.
 *            ADC_Channel_8 - ADC Channel8 selected.
 *            ADC_Channel_9 - ADC Channel9 selected.
 *            ADC_Channel_10 - ADC Channel10 selected.
 *            ADC_Channel_11 - ADC Channel11 selected.
 *            ADC_Channel_12 - ADC Channel12 selected.
 *            ADC_Channel_13 - ADC Channel13 selected.
 *            ADC_Channel_14 - ADC Channel14 selected.
 *            ADC_Channel_15 - ADC Channel15 selected.
 *            ADC_Channel_16 - ADC Channel16 selected.
 *            ADC_Channel_17 - ADC Channel17 selected.
 *
 * @return  none
 */
u16 Get_ADC_Val(u8 ch)
{
    u16 val;

    ADC_RegularChannelConfig(ADC1, ch, 1, ADC_SampleTime_239Cycles5 );
    ADC_SoftwareStartConvCmd(ADC1, ENABLE);

    while(!ADC_GetFlagStatus(ADC1, ADC_FLAG_EOC ));
    val = ADC_GetConversionValue(ADC1);

    return val;
}

/*********************************************************************
 * @fn      DMA_Tx_Init
 *
 * @brief   Initializes the DMAy Channelx configuration.
 *
 * @param   DMA_CHx - x can be 1 to 7.
 *          ppadr - Peripheral base address.
 *          memadr - Memory base address.
 *          bufsize - DMA channel buffer size.
 *
 * @return  none
 */
void DMA_Tx_Init()
{
//    DMA_InitTypeDef DMA_InitStructure={0};
//    NVIC_InitTypeDef NVIC_InitStructure = {0};
//    RCC_AHBPeriphClockCmd( RCC_AHBPeriph_DMA1, ENABLE );
//
//    DMA_DeInit(DMA_CHx);
//    DMA_InitStructure.DMA_PeripheralBaseAddr = ppadr;
//    DMA_InitStructure.DMA_MemoryBaseAddr = memadr;
//    DMA_InitStructure.DMA_DIR = DMA_DIR_PeripheralSRC;
//    DMA_InitStructure.DMA_BufferSize = bufsize;
//    DMA_InitStructure.DMA_PeripheralInc = DMA_PeripheralInc_Disable;
//    DMA_InitStructure.DMA_MemoryInc = DMA_MemoryInc_Enable;
//    DMA_InitStructure.DMA_PeripheralDataSize = DMA_PeripheralDataSize_HalfWord;
//    DMA_InitStructure.DMA_MemoryDataSize = DMA_MemoryDataSize_HalfWord;
//    DMA_InitStructure.DMA_Mode = DMA_Mode_Normal;
//    DMA_InitStructure.DMA_Priority = DMA_Priority_VeryHigh;
//    DMA_InitStructure.DMA_M2M = DMA_M2M_Disable;
//    DMA_Init( DMA_CHx, &DMA_InitStructure );
//
//    NVIC_InitStructure.NVIC_IRQChannel = DMA1_Channel1_IRQn;
//    NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 2;
//    NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
//    NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
//    NVIC_Init(&NVIC_InitStructure);
//
//    DMA_ITConfig(DMA1_Channel1, DMA_IT_TC, ENABLE);
    DMA_InitTypeDef  DMA_InitStructure;
    NVIC_InitTypeDef NVIC_InitStructure;

    RCC_AHBPeriphClockCmd( RCC_AHBPeriph_DMA1, ENABLE ); //使能开启DMA时钟

    DMA_DeInit(DMA1_Channel1); //复位DMA控制器

    DMA_InitStructure.DMA_PeripheralBaseAddr = (u32)&ADC1->RDATAR;  //配置外设地址为ADC数据寄存器地址
    DMA_InitStructure.DMA_MemoryBaseAddr = (u32)TxBuf; //配置存储器地址为读取ADC值地址
    DMA_InitStructure.DMA_DIR = DMA_DIR_PeripheralSRC;              //配置数据源为外设，即DMA传输方式为外设到存储器
    DMA_InitStructure.DMA_BufferSize = 240;                      //设置DMA数据缓冲区大小，此处设置为length
    DMA_InitStructure.DMA_PeripheralInc = DMA_PeripheralInc_Disable;//设置DMA外设递增模式关闭
    DMA_InitStructure.DMA_MemoryInc = DMA_MemoryInc_Enable;         //设置DMA存储器递增模式开启
    DMA_InitStructure.DMA_PeripheralDataSize = DMA_PeripheralDataSize_HalfWord; //设置外设数据大小为半字，即两个字节
    DMA_InitStructure.DMA_MemoryDataSize = DMA_MemoryDataSize_HalfWord;         //设置存储器数据大小为半字，即两个字节
    DMA_InitStructure.DMA_Mode = DMA_Mode_Circular;     //设置DMA模式为循环传输模式
    DMA_InitStructure.DMA_Priority = DMA_Priority_High; //设置DMA传输通道优先级为高，当使用一 DMA通道时，优先级设置不影响
    DMA_InitStructure.DMA_M2M = DMA_M2M_Disable;        //因为此DMA传输方式为外设到存储器，因此禁用存储器到存储器传输方式
    DMA_Init( DMA1_Channel1, &DMA_InitStructure );      //初始化DMA

    DMA_ITConfig(DMA1_Channel1,DMA_IT_TC, ENABLE);      //使能传输完成中断

    NVIC_InitStructure.NVIC_IRQChannel = DMA1_Channel1_IRQn;
    NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 3;
    NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
    NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
    NVIC_Init(&NVIC_InitStructure);

    DMA_Cmd(DMA1_Channel1 , ENABLE);  //使能DMA

}

/*********************************************************************
 * @fn      Get_ConversionVal
 *
 * @brief   Get Conversion Value.
 *
 * @param   val - Sampling value
 *
 * @return  val+Calibrattion_Val - Conversion Value.
 */
u16 Get_ConversionVal(s16 val)
{
    if((val+Calibrattion_Val)<0) return 0;
    if((Calibrattion_Val+val)>4095||val==4095) return 4095;
    return (val+Calibrattion_Val);
}

/*********************************************************************
 * @fn      main
 *
 * @brief   Main program
 *
 * @return  none
 */
int main(void)
{
    u16 i;
    NVIC_PriorityGroupConfig(NVIC_PriorityGroup_2);
    SystemCoreClockUpdate();
    Delay_Init();
    USART_Printf_Init(115200);                                    //USART initialize
    DMA_Tx_Init();
    ADC_Function_Init();
    ADC_RegularChannelConfig(ADC1, ADC_Channel_1, 1, ADC_SampleTime_28Cycles5);
    Time_Init();
//    printf("UdpServer Test\r\n");
//    printf("SystemClk:%d\r\n", SystemCoreClock);
//    printf( "ChipID:%08x\r\n", DBGMCU_GetCHIPID() );
//    printf("net version:%x\n", WCHNET_GetVer());
//    if ( WCHNET_LIB_VER != WCHNET_GetVer()) {
//        printf("version error.\n");
//    }
//    WCHNET_GetMacAddr(MACAddr);                                   //get the chip MAC address
//    printf("mac addr:");
//    for(i = 0; i < 6; i++)
//        printf("%x ",MACAddr[i]);
//    printf("\n");
//    TIM2_Init();
//    i = ETH_LibInit(IPAddr, GWIPAddr, IPMask, MACAddr);           //Ethernet library initialize
//    mStopIfError(i);
//    if (i == WCHNET_ERR_SUCCESS)
//        printf("WCHNET_LibInit Success\r\n");
//    WCHNET_CreateUdpSocket();                                     //Create  UDP Socket

    while(1)
    {
//        /*Ethernet library main task function,
//         * which needs to be called cyclically*/
//        WCHNET_MainTask();
//        /*Query the Ethernet global interrupt,
//         * if there is an interrupt, call the global interrupt handler*/
//        if(WCHNET_QueryGlobalInt())
//        {
//            WCHNET_HandleGlobalInt();
//        }
    }
}
void DMA1_Channel1_IRQHandler(void) __attribute__((interrupt("WCH-Interrupt-fast")));
/*********************************************************************
 * @fn      DMA1_Channel1_IRQHandler
 *
 * @brief   DMA1_Channel1_IRQHandler Interrupt Service Function.
 *
 * @return  none
 */
void DMA1_Channel1_IRQHandler()
{

    static u32 len = 240;
    static u8 i ;

//    i++;
    if(DMA_GetITStatus(DMA1_IT_TC1) == SET)
    {


for (u8  j= 0; j  < 240; ++j ) {
    Adc_Val[j] = TxBuf[j] & 0xffff;
}


//        Adc_Val[1]= (TxBuf[0] >> 16) & 0xffff;
//        len = WCHNET_SocketSend(0, (u8 *) Adc_Val, &len);
//        printf("%d\r\n", i);
        printf("%d\r\n", Get_ConversionVal(Adc_Val[0]));


    }
    DMA_ClearITPendingBit(DMA1_IT_TC1);

}
